@@ -1,11 +1,11 @@
-use cs_trace::{create_trace_listener, TraceListenerOptions, Trace, SubscriberInitExt, create_trace, child};
+use cs_trace::{create_trace_listener, TraceListenerOptions, SubscriberInitExt, create_trace, child};
 use cs_utils::random_str;
 
 fn main() {
     let collector = create_trace_listener(
         TraceListenerOptions::new()
                 .with_stdout(true)
-                .with_file_path("./simple-example.log")
+                .with_file_path("./simple-example.log", false)
                 .with_env_filter("[crate-name],[child]"),
     );
 
