@@ -7,7 +7,7 @@ use cs_utils::random_str;
 #[test]
 #[should_panic]
 fn panics_if_invalid_file_path() {
-    let _ = FileWriter::new("");
+    let _ = FileWriter::new("", false);
 }
 
 #[test]
@@ -56,7 +56,7 @@ fn create_log_writer<'a>(folder_name: String) -> (String, String, Box<dyn Write>
     let file_folder = format!("/tmp/utils/{}", folder_name);
     let file_name = format!("{}/logs.log", file_folder);
 
-    let file_writer = FileWriter::new(&file_name);
+    let file_writer = FileWriter::new(&file_name, false);
 
     return (file_folder, file_name, file_writer);
 }
